/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.qpid.jms.provider.discovery;

import java.net.URI;

/**
 * A listener of services being added or removed from a network
 */
public interface DiscoveryListener {

    /**
     * Called when a DiscoveryAgent becomes aware of a new remote peer.
     *
     * @param remoteURI
     *        the URI of the newly discovered peer.
     */
    void onServiceAdd(URI remoteURI);

    /**
     * Called when a DiscoveryAgent can no longer detect a previously known remote peer.
     *
     * @param remoteURI
     *        the URI of the previously discovered peer that is no longer active.
     */
    void onServiceRemove(URI remoteURI);

}
